/******************************** -*- C -*- ****************************
 *
 *	Sample call to printf using GNU lightning
 *
 ***********************************************************************/


/***********************************************************************
 *
 * Copyright 2000 Free Software Foundation, Inc.
 * Written by Paolo Bonzini.
 *
 * This file is part of GNU lightning.
 *
 * GNU lightning is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1, or (at your option)
 * any later version.
 * 
 * GNU lightning is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with GNU lightning; see the file COPYING.LESSER; if not, write to the
 * Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 ***********************************************************************/


#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include "lightning.h"

typedef int (*pifi)(int);
   /* Pointer to Int Function of Int */

void test(void);

int main(void)
{
  jit_insn *codeBuffer = calloc(1, 1024);
  pifi incr = (pifi) (jit_set_ip(codeBuffer).iptr);
  int in;
     
  jit_leaf(1);
  in = jit_arg_i();
  jit_getarg_i(JIT_R0, in);
  jit_addi_i(JIT_R0, JIT_R0, 1);
  jit_movr_i(JIT_RET, JIT_R0);
  jit_ret();
       
  jit_flush_code(codeBuffer, jit_get_ip().ptr);
     
  /* call the generated code, passing 5 as an argument */
  printf("%d + 1 = %d\n", 5, incr(5));
  test();
  return 0;
}

void test(void)
{
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
  printf("this is a test\n");
}
